@@ -219,7 +219,9 @@ class LabelPrinterScreen(Screen):
 
         main_grid.add_widget(label_grid)
 
-        main_grid.slide_label_printer_button = Button(text="Back to main screen", size_hint=(1, 0.1))
+        main_grid.slide_label_printer_button = Button(
+            text="Back to main screen", size_hint=(1, 0.1)
+        )
         main_grid.slide_label_printer_button.bind(on_press=self.changer)
         main_grid.add_widget(main_grid.slide_label_printer_button)
 
@@ -262,7 +264,13 @@ class LabelPrinterScreen(Screen):
         quantity = int(self.quantity_textbox.text)
 
         Thread(
-            target=partial(label_print.print_text, text, quantity=quantity, print_date=self.date_checkbox.active, barcode=barcode)
+            target=partial(
+                label_print.print_text,
+                text,
+                quantity=quantity,
+                print_date=self.date_checkbox.active,
+                barcode=barcode,
+            )
         ).start()
         self.barcode_textbox.text = "Barcode"
         self.quantity_textbox.text = "1"
