@@ -1,8 +1,8 @@
 """Sync cogs to discord to enable /commands"""
 import asyncio
+import importlib.metadata
 import os
 import platform
-import pkg_resources
 import luddite
 import discord
 from discord.ext import commands
@@ -24,8 +24,11 @@ class SetupCog(commands.Cog):
         """Add slash commands to Discord guid"""
         if platform.node().lower() == "secureerase":
             await context.defer()
-            if pkg_resources.get_distribution("shiny_api") != luddite.get_version_pypi("shiny_api"):
-                quit()
+
+            print(importlib.metadata.version("shiny_api"))
+            print(luddite.get_version_pypi("shiny_api"))
+            if importlib.metadata.version("shiny_api") != luddite.get_version_pypi("shiny_api"):
+                os._exit(1)
             await asyncio.sleep(2)
 
         try:
